@@ -74,7 +74,7 @@ impl TailwindInstruction {
             ["content", rest @ ..] => TailwindContent::adapt(rest, arbitrary)?,
             ["items", rest @ ..] => TailwindItems::parse(rest, arbitrary)?.boxed(),
             ["self", rest @ ..] => TailwindSelf::parse(rest, arbitrary)?.boxed(),
-            ["place", rest @ ..] => TailwindPlace::parse(rest, arbitrary)?,
+            ["place", rest @ ..] => TailwindPlace::adapt(rest, arbitrary)?,
             // justify catched
             // Spacing System
             ["p" | "pl" | "pr" | "pb" | "pt" | "px" | "py", ..] => TailwindPadding::parse(pattern, arbitrary, neg)?.boxed(),
@@ -235,7 +235,9 @@ impl TailwindInstruction {
     #[inline]
     fn box_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
+            // https://tailwindcss.com/docs/box-decoration-break
             ["decoration", rest @ ..] => TailwindBoxDecoration::parse(rest, arbitrary)?.boxed(),
+
             ["border"] => TailwindBoxSizing::from("border").boxed(),
             ["content"] => TailwindBoxSizing::from("content").boxed(),
             _ => return syntax_error!("Unknown box instructions: {}", str.join("-")),
